import { eventWithTime, listenerHandler } from '@highlight-run/rrweb/typings/types';
import { FirstLoadListeners } from './listeners/first-load-listeners';
import { ConsoleMethods, DebugOptions, FeedbackWidgetOptions, NetworkRecordingOptions, SessionShortcutOptions } from '../../firstload/src/types/client';
import { SamplingStrategy } from '../../firstload/src/types/types';
import { PushPayloadMutationVariables, Sdk } from './graph/generated/operations';
import { Agent } from '@highlight-run/fingerprintjs';
import { SessionData } from './utils/sessionStorage/highlightSession';
import type { HighlightClientRequestWorker } from './workers/highlight-client-worker';
import { PropertyType, Source } from './workers/types';
import { Logger } from './logger';
export declare const HighlightWarning: (context: string, msg: any) => void;
export declare type HighlightClassOptions = {
    organizationID: number | string;
    debug?: boolean | DebugOptions;
    backendUrl?: string;
    tracingOrigins?: boolean | (string | RegExp)[];
    disableNetworkRecording?: boolean;
    networkRecording?: boolean | NetworkRecordingOptions;
    disableConsoleRecording?: boolean;
    consoleMethodsToRecord?: ConsoleMethods[];
    enableSegmentIntegration?: boolean;
    enableStrictPrivacy?: boolean;
    enableCanvasRecording?: boolean;
    samplingStrategy?: SamplingStrategy;
    inlineImages?: boolean;
    inlineStylesheet?: boolean;
    firstloadVersion?: string;
    environment?: 'development' | 'production' | 'staging' | string;
    appVersion?: string;
    sessionShortcut?: SessionShortcutOptions;
    feedbackWidget?: FeedbackWidgetOptions;
    sessionSecureID: string;
};
/**
 * Subset of HighlightClassOptions that is stored with the session. These fields are stored for debugging purposes.
 */
declare type HighlightClassOptionsInternal = Omit<HighlightClassOptions, 'firstloadVersion'>;
export declare class Highlight {
    options: HighlightClassOptions;
    /** Determines if the client is running on a Highlight property (e.g. frontend). */
    isRunningOnHighlight: boolean;
    /** Verbose project ID that is exposed to users. Legacy users may still be using ints. */
    organizationID: string;
    graphqlSDK: Sdk;
    events: eventWithTime[];
    sessionData: SessionData;
    ready: boolean;
    state: 'NotRecording' | 'Recording';
    logger: Logger;
    fingerprintjs: Promise<Agent>;
    enableSegmentIntegration: boolean;
    enableStrictPrivacy: boolean;
    enableCanvasRecording: boolean;
    samplingStrategy: SamplingStrategy;
    inlineImages: boolean;
    inlineStylesheet: boolean;
    debugOptions: DebugOptions;
    listeners: listenerHandler[];
    firstloadVersion: string;
    environment: string;
    sessionShortcut: SessionShortcutOptions;
    /** The end-user's app version. This isn't Highlight's version. */
    appVersion: string | undefined;
    _worker: HighlightClientRequestWorker;
    _optionsInternal: HighlightClassOptionsInternal;
    _backendUrl: string;
    _recordingStartTime: number;
    _isOnLocalHost: boolean;
    _onToggleFeedbackFormVisibility: () => void;
    _firstLoadListeners: FirstLoadListeners;
    _eventBytesSinceSnapshot: number;
    _lastSnapshotTime: number;
    _lastVisibilityChangeTime: number;
    pushPayloadTimerId: ReturnType<typeof setTimeout> | undefined;
    feedbackWidgetOptions: FeedbackWidgetOptions;
    hasSessionUnloaded: boolean;
    hasPushedData: boolean;
    reloaded: boolean;
    _hasPreviouslyInitialized: boolean;
    recordStop: (() => void) | undefined;
    _payloadId: number;
    static create(options: HighlightClassOptions): Highlight;
    constructor(options: HighlightClassOptions, firstLoadListeners?: FirstLoadListeners);
    _reset(): Promise<void>;
    _initMembers(options: HighlightClassOptions): void;
    identify(user_identifier: string, user_object?: {}, source?: Source): void;
    pushCustomError(message: string, payload?: string): Promise<void>;
    consumeCustomError(error: Error, message?: string, payload?: string): Promise<void>;
    addProperties(properties_obj?: {}, typeArg?: PropertyType): void;
    initialize(): Promise<undefined>;
    _visibilityHandler(hidden: boolean): Promise<void>;
    _setupWindowListeners(): void;
    /**
     * Stops Highlight from recording.
     * @param manual The end user requested to stop recording.
     */
    stopRecording(manual?: boolean): void;
    getCurrentSessionTimestamp(): number;
    /**
     * Returns the current timestamp for the current session.
     */
    getCurrentSessionURLWithTimestamp(): string;
    getCurrentSessionURL(): string | null;
    toggleFeedbackWidgetVisibility(): void;
    addSessionFeedback({ timestamp, verbatim, user_email, user_name, }: {
        verbatim: string;
        timestamp: string;
        user_name?: string;
        user_email?: string;
    }): void;
    _save(): Promise<void>;
    /**
     * This proxy should be used instead of rrweb's native addCustomEvent.
     * The proxy makes sure recording has started before emitting a custom event.
     */
    addCustomEvent<T>(tag: string, payload: T): void;
    _sendPayload({ isBeacon, sendFn, }: {
        isBeacon: boolean;
        sendFn?: (payload: PushPayloadMutationVariables) => Promise<number>;
    }): Promise<void>;
}
declare global {
    interface Console {
        defaultLog: any;
        defaultError: any;
        defaultWarn: any;
        defaultDebug: any;
    }
}
export {};
